# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rpas-india/FlightLog.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rpas-india/FlightLog.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=b'\n\x1arpas-india/FlightLog.proto\"7\n\x03Log\x12\x1d\n\tflightLog\x18\x01 \x01(\x0b\x32\n.FlightLog\x12\x11\n\tsignature\x18\x02 \x01(\x0c\"\xd8\x02\n\tFlightLog\x12\x1a\n\x12permissionArtefact\x18\x01 \x01(\t\x12\'\n\nlogEntries\x18\x02 \x03(\x0b\x32\x13.FlightLog.LogEntry\x12\x17\n\x0fpreviousLogHash\x18\x03 \x01(\x0c\x1a\x8a\x01\n\x08LogEntry\x12\'\n\tentryType\x18\x01 \x01(\x0e\x32\x14.FlightLog.EntryType\x12\x11\n\ttimestamp\x18\x02 \x01(\x04\x12\x11\n\tlongitude\x18\x03 \x01(\x01\x12\x10\n\x08latitude\x18\x04 \x01(\x01\x12\x10\n\x08\x61ltitude\x18\x05 \x01(\x01\x12\x0b\n\x03\x63rc\x18\x06 \x01(\x0c\"`\n\tEntryType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0f\n\x0bTAKEOFF_ARM\x10\x01\x12\x13\n\x0fGEOFENCE_BREACH\x10\x02\x12\x0f\n\x0bTIME_BREACH\x10\x03\x12\x0f\n\x0bLAND_DISARM\x10\x04\x62\x06proto3'
)



_FLIGHTLOG_ENTRYTYPE = _descriptor.EnumDescriptor(
  name='EntryType',
  full_name='FlightLog.EntryType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TAKEOFF_ARM', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GEOFENCE_BREACH', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TIME_BREACH', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LAND_DISARM', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=336,
  serialized_end=432,
)
_sym_db.RegisterEnumDescriptor(_FLIGHTLOG_ENTRYTYPE)


_LOG = _descriptor.Descriptor(
  name='Log',
  full_name='Log',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='flightLog', full_name='Log.flightLog', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signature', full_name='Log.signature', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=30,
  serialized_end=85,
)


_FLIGHTLOG_LOGENTRY = _descriptor.Descriptor(
  name='LogEntry',
  full_name='FlightLog.LogEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entryType', full_name='FlightLog.LogEntry.entryType', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='FlightLog.LogEntry.timestamp', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='longitude', full_name='FlightLog.LogEntry.longitude', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='latitude', full_name='FlightLog.LogEntry.latitude', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='altitude', full_name='FlightLog.LogEntry.altitude', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='crc', full_name='FlightLog.LogEntry.crc', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=196,
  serialized_end=334,
)

_FLIGHTLOG = _descriptor.Descriptor(
  name='FlightLog',
  full_name='FlightLog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='permissionArtefact', full_name='FlightLog.permissionArtefact', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='logEntries', full_name='FlightLog.logEntries', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='previousLogHash', full_name='FlightLog.previousLogHash', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_FLIGHTLOG_LOGENTRY, ],
  enum_types=[
    _FLIGHTLOG_ENTRYTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=88,
  serialized_end=432,
)

_LOG.fields_by_name['flightLog'].message_type = _FLIGHTLOG
_FLIGHTLOG_LOGENTRY.fields_by_name['entryType'].enum_type = _FLIGHTLOG_ENTRYTYPE
_FLIGHTLOG_LOGENTRY.containing_type = _FLIGHTLOG
_FLIGHTLOG.fields_by_name['logEntries'].message_type = _FLIGHTLOG_LOGENTRY
_FLIGHTLOG_ENTRYTYPE.containing_type = _FLIGHTLOG
DESCRIPTOR.message_types_by_name['Log'] = _LOG
DESCRIPTOR.message_types_by_name['FlightLog'] = _FLIGHTLOG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Log = _reflection.GeneratedProtocolMessageType('Log', (_message.Message,), {
  'DESCRIPTOR' : _LOG,
  '__module__' : 'rpas_india.FlightLog_pb2'
  # @@protoc_insertion_point(class_scope:Log)
  })
_sym_db.RegisterMessage(Log)

FlightLog = _reflection.GeneratedProtocolMessageType('FlightLog', (_message.Message,), {

  'LogEntry' : _reflection.GeneratedProtocolMessageType('LogEntry', (_message.Message,), {
    'DESCRIPTOR' : _FLIGHTLOG_LOGENTRY,
    '__module__' : 'rpas_india.FlightLog_pb2'
    # @@protoc_insertion_point(class_scope:FlightLog.LogEntry)
    })
  ,
  'DESCRIPTOR' : _FLIGHTLOG,
  '__module__' : 'rpas_india.FlightLog_pb2'
  # @@protoc_insertion_point(class_scope:FlightLog)
  })
_sym_db.RegisterMessage(FlightLog)
_sym_db.RegisterMessage(FlightLog.LogEntry)


# @@protoc_insertion_point(module_scope)
