# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rpas-india/PermissionArtefact.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rpas-india/PermissionArtefact.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=b'\n#rpas-india/PermissionArtefact.proto\"\xd1\x01\n\x0cUAPermission\x12\x13\n\x0blastUpdated\x18\x01 \x01(\x04\x12\x0b\n\x03ttl\x18\x02 \x01(\x02\x12\r\n\x05txnId\x18\x03 \x01(\t\x12\x1c\n\x14permissionartefactId\x18\x04 \x01(\t\x12\x14\n\x0cpilotPinHash\x18\x05 \x01(\t\x12\x1b\n\x08operator\x18\x06 \x01(\x0b\x32\t.Operator\x12%\n\rflightDetails\x18\x07 \x01(\x0b\x32\x0e.FlightDetails\x12\x18\n\x10\x64igitalSignature\x18\x08 \x01(\x0c\"d\n\x08Operator\x12\x12\n\noperatorID\x18\x01 \x01(\t\x12\x1e\n\x05pilot\x18\x02 \x01(\x0b\x32\x0f.Operator.Pilot\x1a$\n\x05Pilot\x12\n\n\x02no\x18\x01 \x01(\t\x12\x0f\n\x07validTo\x18\x02 \x01(\x04\"\xb8\x04\n\rFlightDetails\x12+\n\tuaDetails\x18\x01 \x01(\x0b\x32\x18.FlightDetails.UADetails\x12\x33\n\rflightPurpose\x18\x02 \x01(\x0b\x32\x1c.FlightDetails.FlightPurpose\x12\x35\n\x0epayloadDetails\x18\x03 \x01(\x0b\x32\x1d.FlightDetails.PayloadDetails\x12\x39\n\x10\x66lightParameters\x18\x04 \x01(\x0b\x32\x1f.FlightDetails.FlightParameters\x1a\x1a\n\tUADetails\x12\r\n\x05uinNo\x18\x01 \x01(\t\x1a\x35\n\rFlightPurpose\x12\x11\n\tshortDesc\x18\x01 \x01(\t\x12\x11\n\tfrequency\x18\x02 \x01(\r\x1a?\n\x0ePayloadDetails\x12\x15\n\rpayLoadWeight\x18\x01 \x01(\x01\x12\x16\n\x0epayloadDetails\x18\x02 \x01(\t\x1a\x31\n\nCoordinate\x12\x10\n\x08latitude\x18\x01 \x01(\x01\x12\x11\n\tlongitude\x18\x02 \x01(\x01\x1a\x8b\x01\n\x10\x46lightParameters\x12.\n\x0b\x63oordinates\x18\x01 \x03(\x0b\x32\x19.FlightDetails.Coordinate\x12\x17\n\x0f\x66lightStartTime\x18\x02 \x01(\x04\x12\x15\n\rflightEndTime\x18\x03 \x01(\x04\x12\x17\n\x0f\x66requenciesUsed\x18\x04 \x01(\x02\x62\x06proto3'
)




_UAPERMISSION = _descriptor.Descriptor(
  name='UAPermission',
  full_name='UAPermission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lastUpdated', full_name='UAPermission.lastUpdated', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ttl', full_name='UAPermission.ttl', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='txnId', full_name='UAPermission.txnId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='permissionartefactId', full_name='UAPermission.permissionartefactId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pilotPinHash', full_name='UAPermission.pilotPinHash', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operator', full_name='UAPermission.operator', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flightDetails', full_name='UAPermission.flightDetails', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='digitalSignature', full_name='UAPermission.digitalSignature', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=40,
  serialized_end=249,
)


_OPERATOR_PILOT = _descriptor.Descriptor(
  name='Pilot',
  full_name='Operator.Pilot',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='no', full_name='Operator.Pilot.no', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validTo', full_name='Operator.Pilot.validTo', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=315,
  serialized_end=351,
)

_OPERATOR = _descriptor.Descriptor(
  name='Operator',
  full_name='Operator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='operatorID', full_name='Operator.operatorID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pilot', full_name='Operator.pilot', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_OPERATOR_PILOT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=251,
  serialized_end=351,
)


_FLIGHTDETAILS_UADETAILS = _descriptor.Descriptor(
  name='UADetails',
  full_name='FlightDetails.UADetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uinNo', full_name='FlightDetails.UADetails.uinNo', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=583,
  serialized_end=609,
)

_FLIGHTDETAILS_FLIGHTPURPOSE = _descriptor.Descriptor(
  name='FlightPurpose',
  full_name='FlightDetails.FlightPurpose',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='shortDesc', full_name='FlightDetails.FlightPurpose.shortDesc', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frequency', full_name='FlightDetails.FlightPurpose.frequency', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=611,
  serialized_end=664,
)

_FLIGHTDETAILS_PAYLOADDETAILS = _descriptor.Descriptor(
  name='PayloadDetails',
  full_name='FlightDetails.PayloadDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='payLoadWeight', full_name='FlightDetails.PayloadDetails.payLoadWeight', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payloadDetails', full_name='FlightDetails.PayloadDetails.payloadDetails', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=666,
  serialized_end=729,
)

_FLIGHTDETAILS_COORDINATE = _descriptor.Descriptor(
  name='Coordinate',
  full_name='FlightDetails.Coordinate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='latitude', full_name='FlightDetails.Coordinate.latitude', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='longitude', full_name='FlightDetails.Coordinate.longitude', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=731,
  serialized_end=780,
)

_FLIGHTDETAILS_FLIGHTPARAMETERS = _descriptor.Descriptor(
  name='FlightParameters',
  full_name='FlightDetails.FlightParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='coordinates', full_name='FlightDetails.FlightParameters.coordinates', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flightStartTime', full_name='FlightDetails.FlightParameters.flightStartTime', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flightEndTime', full_name='FlightDetails.FlightParameters.flightEndTime', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frequenciesUsed', full_name='FlightDetails.FlightParameters.frequenciesUsed', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=783,
  serialized_end=922,
)

_FLIGHTDETAILS = _descriptor.Descriptor(
  name='FlightDetails',
  full_name='FlightDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uaDetails', full_name='FlightDetails.uaDetails', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flightPurpose', full_name='FlightDetails.flightPurpose', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payloadDetails', full_name='FlightDetails.payloadDetails', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flightParameters', full_name='FlightDetails.flightParameters', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_FLIGHTDETAILS_UADETAILS, _FLIGHTDETAILS_FLIGHTPURPOSE, _FLIGHTDETAILS_PAYLOADDETAILS, _FLIGHTDETAILS_COORDINATE, _FLIGHTDETAILS_FLIGHTPARAMETERS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=354,
  serialized_end=922,
)

_UAPERMISSION.fields_by_name['operator'].message_type = _OPERATOR
_UAPERMISSION.fields_by_name['flightDetails'].message_type = _FLIGHTDETAILS
_OPERATOR_PILOT.containing_type = _OPERATOR
_OPERATOR.fields_by_name['pilot'].message_type = _OPERATOR_PILOT
_FLIGHTDETAILS_UADETAILS.containing_type = _FLIGHTDETAILS
_FLIGHTDETAILS_FLIGHTPURPOSE.containing_type = _FLIGHTDETAILS
_FLIGHTDETAILS_PAYLOADDETAILS.containing_type = _FLIGHTDETAILS
_FLIGHTDETAILS_COORDINATE.containing_type = _FLIGHTDETAILS
_FLIGHTDETAILS_FLIGHTPARAMETERS.fields_by_name['coordinates'].message_type = _FLIGHTDETAILS_COORDINATE
_FLIGHTDETAILS_FLIGHTPARAMETERS.containing_type = _FLIGHTDETAILS
_FLIGHTDETAILS.fields_by_name['uaDetails'].message_type = _FLIGHTDETAILS_UADETAILS
_FLIGHTDETAILS.fields_by_name['flightPurpose'].message_type = _FLIGHTDETAILS_FLIGHTPURPOSE
_FLIGHTDETAILS.fields_by_name['payloadDetails'].message_type = _FLIGHTDETAILS_PAYLOADDETAILS
_FLIGHTDETAILS.fields_by_name['flightParameters'].message_type = _FLIGHTDETAILS_FLIGHTPARAMETERS
DESCRIPTOR.message_types_by_name['UAPermission'] = _UAPERMISSION
DESCRIPTOR.message_types_by_name['Operator'] = _OPERATOR
DESCRIPTOR.message_types_by_name['FlightDetails'] = _FLIGHTDETAILS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UAPermission = _reflection.GeneratedProtocolMessageType('UAPermission', (_message.Message,), {
  'DESCRIPTOR' : _UAPERMISSION,
  '__module__' : 'rpas_india.PermissionArtefact_pb2'
  # @@protoc_insertion_point(class_scope:UAPermission)
  })
_sym_db.RegisterMessage(UAPermission)

Operator = _reflection.GeneratedProtocolMessageType('Operator', (_message.Message,), {

  'Pilot' : _reflection.GeneratedProtocolMessageType('Pilot', (_message.Message,), {
    'DESCRIPTOR' : _OPERATOR_PILOT,
    '__module__' : 'rpas_india.PermissionArtefact_pb2'
    # @@protoc_insertion_point(class_scope:Operator.Pilot)
    })
  ,
  'DESCRIPTOR' : _OPERATOR,
  '__module__' : 'rpas_india.PermissionArtefact_pb2'
  # @@protoc_insertion_point(class_scope:Operator)
  })
_sym_db.RegisterMessage(Operator)
_sym_db.RegisterMessage(Operator.Pilot)

FlightDetails = _reflection.GeneratedProtocolMessageType('FlightDetails', (_message.Message,), {

  'UADetails' : _reflection.GeneratedProtocolMessageType('UADetails', (_message.Message,), {
    'DESCRIPTOR' : _FLIGHTDETAILS_UADETAILS,
    '__module__' : 'rpas_india.PermissionArtefact_pb2'
    # @@protoc_insertion_point(class_scope:FlightDetails.UADetails)
    })
  ,

  'FlightPurpose' : _reflection.GeneratedProtocolMessageType('FlightPurpose', (_message.Message,), {
    'DESCRIPTOR' : _FLIGHTDETAILS_FLIGHTPURPOSE,
    '__module__' : 'rpas_india.PermissionArtefact_pb2'
    # @@protoc_insertion_point(class_scope:FlightDetails.FlightPurpose)
    })
  ,

  'PayloadDetails' : _reflection.GeneratedProtocolMessageType('PayloadDetails', (_message.Message,), {
    'DESCRIPTOR' : _FLIGHTDETAILS_PAYLOADDETAILS,
    '__module__' : 'rpas_india.PermissionArtefact_pb2'
    # @@protoc_insertion_point(class_scope:FlightDetails.PayloadDetails)
    })
  ,

  'Coordinate' : _reflection.GeneratedProtocolMessageType('Coordinate', (_message.Message,), {
    'DESCRIPTOR' : _FLIGHTDETAILS_COORDINATE,
    '__module__' : 'rpas_india.PermissionArtefact_pb2'
    # @@protoc_insertion_point(class_scope:FlightDetails.Coordinate)
    })
  ,

  'FlightParameters' : _reflection.GeneratedProtocolMessageType('FlightParameters', (_message.Message,), {
    'DESCRIPTOR' : _FLIGHTDETAILS_FLIGHTPARAMETERS,
    '__module__' : 'rpas_india.PermissionArtefact_pb2'
    # @@protoc_insertion_point(class_scope:FlightDetails.FlightParameters)
    })
  ,
  'DESCRIPTOR' : _FLIGHTDETAILS,
  '__module__' : 'rpas_india.PermissionArtefact_pb2'
  # @@protoc_insertion_point(class_scope:FlightDetails)
  })
_sym_db.RegisterMessage(FlightDetails)
_sym_db.RegisterMessage(FlightDetails.UADetails)
_sym_db.RegisterMessage(FlightDetails.FlightPurpose)
_sym_db.RegisterMessage(FlightDetails.PayloadDetails)
_sym_db.RegisterMessage(FlightDetails.Coordinate)
_sym_db.RegisterMessage(FlightDetails.FlightParameters)


# @@protoc_insertion_point(module_scope)
