# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: solar-power-production/SolarPowerProductionStatic.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import FeedHeaderStatic_pb2 as FeedHeaderStatic__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='solar-power-production/SolarPowerProductionStatic.proto',
  package='solar_production_static',
  syntax='proto3',
  serialized_options=b'\n\032io.pravah.solar.production',
  serialized_pb=b'\n7solar-power-production/SolarPowerProductionStatic.proto\x12\x17solar_production_static\x1a\x16\x46\x65\x65\x64HeaderStatic.proto\"h\n\x0b\x46\x65\x65\x64Message\x12!\n\x06header\x18\x01 \x01(\x0b\x32\x11.FeedHeaderStatic\x12\x36\n\x08stations\x18\x02 \x03(\x0b\x32$.solar_production_static.FeedStation\"\x99\x02\n\x0b\x46\x65\x65\x64Station\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12=\n\rspecification\x18\x03 \x01(\x0b\x32&.solar_production_static.Specification\x12\x43\n\x10installationSpec\x18\x04 \x01(\x0b\x32).solar_production_static.InstallationSpec\x12\x37\n\x0cinverterList\x18\x05 \x03(\x0b\x32!.solar_production_static.Inverter\x12\x33\n\x08location\x18\x06 \x01(\x0b\x32!.solar_production_static.Location\"\xcf\x01\n\x08Inverter\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12=\n\rspecification\x18\x03 \x01(\x0b\x32&.solar_production_static.Specification\x12\x35\n\tpanelInfo\x18\x04 \x01(\x0b\x32\".solar_production_static.PanelInfo\x12\x33\n\x08location\x18\x05 \x01(\x0b\x32!.solar_production_static.Location\"V\n\tPanelInfo\x12\x12\n\npanelCount\x18\x01 \x01(\r\x12\r\n\x05model\x18\x02 \x01(\t\x12\x14\n\x0cmanufacturer\x18\x03 \x01(\t\x12\x10\n\x08\x63\x61pacity\x18\x04 \x01(\x02\",\n\x10InstallationSpec\x12\x18\n\x10installationType\x18\x01 \x01(\t\"K\n\rSpecification\x12\x15\n\rpowerCapacity\x18\x01 \x01(\x01\x12\r\n\x05model\x18\x02 \x01(\t\x12\x14\n\x0cmanufacturer\x18\x03 \x01(\t\"@\n\x08Location\x12\x10\n\x08latitude\x18\x01 \x01(\x01\x12\x11\n\tlongitude\x18\x02 \x01(\x01\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\tB\x1c\n\x1aio.pravah.solar.productionb\x06proto3'
  ,
  dependencies=[FeedHeaderStatic__pb2.DESCRIPTOR,])




_FEEDMESSAGE = _descriptor.Descriptor(
  name='FeedMessage',
  full_name='solar_production_static.FeedMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='solar_production_static.FeedMessage.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stations', full_name='solar_production_static.FeedMessage.stations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=108,
  serialized_end=212,
)


_FEEDSTATION = _descriptor.Descriptor(
  name='FeedStation',
  full_name='solar_production_static.FeedStation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='solar_production_static.FeedStation.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='solar_production_static.FeedStation.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='specification', full_name='solar_production_static.FeedStation.specification', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='installationSpec', full_name='solar_production_static.FeedStation.installationSpec', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inverterList', full_name='solar_production_static.FeedStation.inverterList', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location', full_name='solar_production_static.FeedStation.location', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=215,
  serialized_end=496,
)


_INVERTER = _descriptor.Descriptor(
  name='Inverter',
  full_name='solar_production_static.Inverter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='solar_production_static.Inverter.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='solar_production_static.Inverter.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='specification', full_name='solar_production_static.Inverter.specification', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='panelInfo', full_name='solar_production_static.Inverter.panelInfo', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location', full_name='solar_production_static.Inverter.location', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=499,
  serialized_end=706,
)


_PANELINFO = _descriptor.Descriptor(
  name='PanelInfo',
  full_name='solar_production_static.PanelInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='panelCount', full_name='solar_production_static.PanelInfo.panelCount', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model', full_name='solar_production_static.PanelInfo.model', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='manufacturer', full_name='solar_production_static.PanelInfo.manufacturer', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='capacity', full_name='solar_production_static.PanelInfo.capacity', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=708,
  serialized_end=794,
)


_INSTALLATIONSPEC = _descriptor.Descriptor(
  name='InstallationSpec',
  full_name='solar_production_static.InstallationSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='installationType', full_name='solar_production_static.InstallationSpec.installationType', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=796,
  serialized_end=840,
)


_SPECIFICATION = _descriptor.Descriptor(
  name='Specification',
  full_name='solar_production_static.Specification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='powerCapacity', full_name='solar_production_static.Specification.powerCapacity', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model', full_name='solar_production_static.Specification.model', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='manufacturer', full_name='solar_production_static.Specification.manufacturer', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=842,
  serialized_end=917,
)


_LOCATION = _descriptor.Descriptor(
  name='Location',
  full_name='solar_production_static.Location',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='latitude', full_name='solar_production_static.Location.latitude', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='longitude', full_name='solar_production_static.Location.longitude', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='address', full_name='solar_production_static.Location.address', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=919,
  serialized_end=983,
)

_FEEDMESSAGE.fields_by_name['header'].message_type = FeedHeaderStatic__pb2._FEEDHEADERSTATIC
_FEEDMESSAGE.fields_by_name['stations'].message_type = _FEEDSTATION
_FEEDSTATION.fields_by_name['specification'].message_type = _SPECIFICATION
_FEEDSTATION.fields_by_name['installationSpec'].message_type = _INSTALLATIONSPEC
_FEEDSTATION.fields_by_name['inverterList'].message_type = _INVERTER
_FEEDSTATION.fields_by_name['location'].message_type = _LOCATION
_INVERTER.fields_by_name['specification'].message_type = _SPECIFICATION
_INVERTER.fields_by_name['panelInfo'].message_type = _PANELINFO
_INVERTER.fields_by_name['location'].message_type = _LOCATION
DESCRIPTOR.message_types_by_name['FeedMessage'] = _FEEDMESSAGE
DESCRIPTOR.message_types_by_name['FeedStation'] = _FEEDSTATION
DESCRIPTOR.message_types_by_name['Inverter'] = _INVERTER
DESCRIPTOR.message_types_by_name['PanelInfo'] = _PANELINFO
DESCRIPTOR.message_types_by_name['InstallationSpec'] = _INSTALLATIONSPEC
DESCRIPTOR.message_types_by_name['Specification'] = _SPECIFICATION
DESCRIPTOR.message_types_by_name['Location'] = _LOCATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FeedMessage = _reflection.GeneratedProtocolMessageType('FeedMessage', (_message.Message,), {
  'DESCRIPTOR' : _FEEDMESSAGE,
  '__module__' : 'solar_power_production.SolarPowerProductionStatic_pb2'
  # @@protoc_insertion_point(class_scope:solar_production_static.FeedMessage)
  })
_sym_db.RegisterMessage(FeedMessage)

FeedStation = _reflection.GeneratedProtocolMessageType('FeedStation', (_message.Message,), {
  'DESCRIPTOR' : _FEEDSTATION,
  '__module__' : 'solar_power_production.SolarPowerProductionStatic_pb2'
  # @@protoc_insertion_point(class_scope:solar_production_static.FeedStation)
  })
_sym_db.RegisterMessage(FeedStation)

Inverter = _reflection.GeneratedProtocolMessageType('Inverter', (_message.Message,), {
  'DESCRIPTOR' : _INVERTER,
  '__module__' : 'solar_power_production.SolarPowerProductionStatic_pb2'
  # @@protoc_insertion_point(class_scope:solar_production_static.Inverter)
  })
_sym_db.RegisterMessage(Inverter)

PanelInfo = _reflection.GeneratedProtocolMessageType('PanelInfo', (_message.Message,), {
  'DESCRIPTOR' : _PANELINFO,
  '__module__' : 'solar_power_production.SolarPowerProductionStatic_pb2'
  # @@protoc_insertion_point(class_scope:solar_production_static.PanelInfo)
  })
_sym_db.RegisterMessage(PanelInfo)

InstallationSpec = _reflection.GeneratedProtocolMessageType('InstallationSpec', (_message.Message,), {
  'DESCRIPTOR' : _INSTALLATIONSPEC,
  '__module__' : 'solar_power_production.SolarPowerProductionStatic_pb2'
  # @@protoc_insertion_point(class_scope:solar_production_static.InstallationSpec)
  })
_sym_db.RegisterMessage(InstallationSpec)

Specification = _reflection.GeneratedProtocolMessageType('Specification', (_message.Message,), {
  'DESCRIPTOR' : _SPECIFICATION,
  '__module__' : 'solar_power_production.SolarPowerProductionStatic_pb2'
  # @@protoc_insertion_point(class_scope:solar_production_static.Specification)
  })
_sym_db.RegisterMessage(Specification)

Location = _reflection.GeneratedProtocolMessageType('Location', (_message.Message,), {
  'DESCRIPTOR' : _LOCATION,
  '__module__' : 'solar_power_production.SolarPowerProductionStatic_pb2'
  # @@protoc_insertion_point(class_scope:solar_production_static.Location)
  })
_sym_db.RegisterMessage(Location)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
